@@ -6,15 +6,21 @@ EXPAND_PARAM = FLEX_FIELDS_OPTIONS.get("EXPAND_PARAM", "expand")
 FIELDS_PARAM = FLEX_FIELDS_OPTIONS.get("FIELDS_PARAM", "fields")
 OMIT_PARAM = FLEX_FIELDS_OPTIONS.get("OMIT_PARAM", "omit")
 
-WILDCARD_EXPAND_VALUES = FLEX_FIELDS_OPTIONS.get(
-    "WILDCARD_EXPAND_VALUES", ["~all", "*"]
-)
+WILDCARD_ALL = "~all"
+WILDCARD_ASTERISK = "*"
+
+if "WILDCARD_EXPAND_VALUES" in FLEX_FIELDS_OPTIONS:
+    WILDCARD_VALUES = FLEX_FIELDS_OPTIONS["WILDCARD_EXPAND_VALUES"]
+elif "WILDCARD_VALUES" in FLEX_FIELDS_OPTIONS:
+    WILDCARD_VALUES = FLEX_FIELDS_OPTIONS["WILDCARD_VALUES"]
+else:
+    WILDCARD_VALUES = [WILDCARD_ALL, WILDCARD_ASTERISK]
 
 assert isinstance(EXPAND_PARAM, str), "'EXPAND_PARAM' should be a string"
 assert isinstance(FIELDS_PARAM, str), "'FIELDS_PARAM' should be a string"
 assert isinstance(OMIT_PARAM, str), "'OMIT_PARAM' should be a string"
 
-if type(WILDCARD_EXPAND_VALUES) not in (list, None):
+if type(WILDCARD_VALUES) not in (list, None):
     raise ValueError("'WILDCARD_EXPAND_VALUES' should be a list of strings or None")
 
 
